@@ -69,6 +69,13 @@ class MediaCategoryViewController: UICollectionViewController, UICollectionViewD
         let name = String(describing: VLCEmptyLibraryView.self)
         let nib = Bundle.main.loadNibNamed(name, owner: self, options: nil)
         guard let emptyView = nib?.first as? VLCEmptyLibraryView else { fatalError("Can't find nib for \(name)") }
+
+        // Check if it is inside a playlist
+        if let collectionModel = model as? CollectionModel,
+            collectionModel.mediaCollection is VLCMLPlaylist {
+            emptyView.contentType = .playlist
+        }
+
         return emptyView
     }()
 
@@ -129,6 +136,16 @@ class MediaCategoryViewController: UICollectionViewController, UICollectionViewD
         return PresentationTheme.current.colors.statusBarStyle
     }
 
+    private func popViewIfNecessary() {
+        // Inside a collection without files
+        if let collectionModel = model as? CollectionModel, collectionModel.anyfiles.isEmpty {
+            // Pop view if collection is not a playlist since a playlist is user created
+            if !(collectionModel.mediaCollection is VLCMLPlaylist) {
+                navigationController?.popViewController(animated: true)
+            }
+        }
+    }
+
     @objc func reloadData() {
         DispatchQueue.main.async {
             [weak self] in
@@ -138,6 +155,10 @@ class MediaCategoryViewController: UICollectionViewController, UICollectionViewD
             self.delegate?.needsToUpdateNavigationbarIfNeeded(self)
             self.collectionView?.reloadData()
             self.updateUIForContent()
+
+            if !self.isSearching {
+                self.popViewIfNecessary()
+            }
         }
     }
 
@@ -167,6 +188,7 @@ class MediaCategoryViewController: UICollectionViewController, UICollectionViewD
         manager.presentingViewController = self
         cachedCellSize = .zero
         collectionView.collectionViewLayout.invalidateLayout()
+        reloadData()
     }
 
     @objc func themeDidChange() {
@@ -197,11 +219,6 @@ class MediaCategoryViewController: UICollectionViewController, UICollectionViewD
         ])
     }
 
-    override func viewDidAppear(_ animated: Bool) {
-        super.viewDidAppear(animated)
-        reloadData()
-    }
-
     func isEmptyCollectionView() -> Bool {
         return collectionView?.numberOfItems(inSection: 0) == 0
     }
@@ -278,7 +295,6 @@ class MediaCategoryViewController: UICollectionViewController, UICollectionViewD
     private func displayEditToolbar() {
         UIView.animate(withDuration: 0.3) { [weak self] in
             self?.editToolbarConstraint?.constant = self?.isEditing == true ? 0 : EditToolbar.height
-            self?.view.layoutIfNeeded()
             self?.collectionView.contentInset = UIEdgeInsets(top: 0, left: 0, bottom: self?.isEditing == true ? EditToolbar.height : 0, right: 0)
         }
     }
@@ -511,6 +527,7 @@ private extension MediaCategoryViewController {
         collectionView?.backgroundColor = PresentationTheme.current.colors.background
         collectionView?.alwaysBounceVertical = true
         longPressGesture = UILongPressGestureRecognizer(target: self, action: #selector(self.handleLongGesture(gesture:)))
+        longPressGesture.minimumPressDuration = 0.2
         collectionView?.addGestureRecognizer(longPressGesture)
         if #available(iOS 11.0, *) {
             collectionView?.contentInsetAdjustmentBehavior = .always
@@ -519,8 +536,15 @@ private extension MediaCategoryViewController {
         }
     }
 
-    @objc func handleLongGesture(gesture: UILongPressGestureRecognizer) {
+    func constrainOnX(_ location: CGPoint, for width: CGFloat) -> CGPoint {
+        var constrainedLocation = location
+        if model.cellType.numberOfColumns(for: width) == 1 {
+            constrainedLocation.x = width / 2
+        }
+        return constrainedLocation
+    }
 
+    @objc func handleLongGesture(gesture: UILongPressGestureRecognizer) {
         switch gesture.state {
         case .began:
             guard let selectedIndexPath = collectionView.indexPathForItem(at: gesture.location(in: collectionView)) else {
@@ -528,7 +552,9 @@ private extension MediaCategoryViewController {
             }
             collectionView.beginInteractiveMovementForItem(at: selectedIndexPath)
         case .changed:
-            collectionView.updateInteractiveMovementTargetPosition(gesture.location(in: gesture.view!))
+            let location = constrainOnX(gesture.location(in: gesture.view!),
+                                        for: collectionView.frame.width)
+            collectionView.updateInteractiveMovementTargetPosition(location)
         case .ended:
             collectionView.endInteractiveMovement()
         default:
