@@ -248,6 +248,19 @@ typedef NS_ENUM(NSInteger, VLCPanType) {
     [self setupRendererDiscovererManager];
 }
 
+- (void)setupMovieViewConstraints
+{
+    _movieViewLeadingConstraint = [_movieView.leadingAnchor constraintEqualToAnchor:self.view.leadingAnchor];
+    _movieViewTrailingConstraint = [_movieView.trailingAnchor constraintEqualToAnchor:self.view.trailingAnchor];
+
+    [NSLayoutConstraint activateConstraints:@[
+        _movieViewLeadingConstraint,
+        _movieViewTrailingConstraint,
+        [_movieView.topAnchor constraintEqualToAnchor:self.view.topAnchor],
+        [_movieView.bottomAnchor constraintEqualToAnchor:self.view.bottomAnchor],
+    ]];
+}
+
 - (void)setupMovieView
 {
     _movieView.translatesAutoresizingMaskIntoConstraints = NO;
@@ -256,17 +269,7 @@ typedef NS_ENUM(NSInteger, VLCPanType) {
         [self.movieView setAccessibilityIgnoresInvertColors:YES];
     }
 
-    _movieViewLeadingConstraint = [_movieView.leadingAnchor constraintEqualToAnchor:self.view.leadingAnchor];
-    _movieViewTrailingConstraint = [_movieView.trailingAnchor constraintEqualToAnchor:self.view.trailingAnchor];
-
-    [NSLayoutConstraint
-     activateConstraints:@[
-                           _movieViewLeadingConstraint,
-                           _movieViewTrailingConstraint,
-                           [_movieView.topAnchor constraintEqualToAnchor:self.view.topAnchor],
-                           [_movieView.bottomAnchor constraintEqualToAnchor:self.view.bottomAnchor],
-                           ]];
-
+    [self setupMovieViewConstraints];
     [self.movieView setAccessibilityIdentifier:@"Video Player Title"];
     [self.movieView setAccessibilityLabel:NSLocalizedString(@"VO_VIDEOPLAYER_TITLE", nil)];
     [self.movieView setAccessibilityHint:NSLocalizedString(@"VO_VIDEOPLAYER_DOUBLETAP", nil)];
@@ -1316,6 +1319,7 @@ currentMediaHasTrackToChooseFrom:(BOOL)currentMediaHasTrackToChooseFrom
     [_playingExternalView updateUIWithRendererItem:_vpc.renderer title:metadata.title];
 
     _audioOnly = metadata.isAudioOnly;
+    _artworkImageView.hidden = !_audioOnly;
 
     #if NEW_UI
         _videoOptionsControlBar.toggleFullScreenButton.hidden = _audioOnly;
@@ -1779,13 +1783,18 @@ currentMediaHasTrackToChooseFrom:(BOOL)currentMediaHasTrackToChooseFrom
         return;
     }
 
+    // Ignore if playing on a external screen since there is no notches.
+    if ([_vpc isPlayingOnExternalScreen]) {
+        return;
+    }
+
     // 30.0 represents the exact size of the notch
     CGFloat constant = _vpc.currentAspectRatio != VLCAspectRatioFillToScreen ? 30.0 : 0.0;
 
-    UIDeviceOrientation orientation = [[UIDevice currentDevice] orientation];
+    UIInterfaceOrientation orientation = [[UIApplication sharedApplication] statusBarOrientation];
 
-    if (orientation == UIDeviceOrientationLandscapeLeft
-        || orientation == UIDeviceOrientationLandscapeRight) {
+    if (orientation == UIInterfaceOrientationLandscapeLeft
+        || orientation == UIInterfaceOrientationLandscapeRight) {
         [_movieViewLeadingConstraint setConstant:constant];
         [_movieViewTrailingConstraint setConstant:-constant];
     } else {
@@ -1946,10 +1955,30 @@ currentMediaHasTrackToChooseFrom:(BOOL)currentMediaHasTrackToChooseFrom
     BOOL displayExternally = view != _movieView;
     [_playingExternalView shouldDisplay:displayExternally movieView:_movieView];
     _artworkImageView.hidden = displayExternally;
+
+    if (displayExternally) {
+        // Adjust constraints for external display
+        UIView *displayView = _playingExternalView.displayView;
+
+        [NSLayoutConstraint activateConstraints:@[
+            [_movieView.leadingAnchor constraintEqualToAnchor:displayView.leadingAnchor],
+            [_movieView.trailingAnchor constraintEqualToAnchor:displayView.trailingAnchor],
+            [_movieView.topAnchor constraintEqualToAnchor:displayView.topAnchor],
+            [_movieView.bottomAnchor constraintEqualToAnchor:displayView.bottomAnchor],
+        ]];
+    }
+
     if (!displayExternally && _movieView.superview != self.view) {
         [self.view addSubview:_movieView];
         [self.view sendSubviewToBack:_movieView];
         _movieView.frame = self.view.frame;
+        _artworkImageView.hidden = !_audioOnly;
+
+        // Adjust constraint for local display
+        [self setupMovieViewConstraints];
+        if (@available(iOS 11, *)) {
+            [self adaptMovieViewToNotch];
+        }
     }
 }
 
