@@ -141,13 +141,11 @@ NSString * const kVLCSectionTableHeaderViewIdentifier = @"VLCSectionTableHeaderV
             PAPasscodeViewController *passcodeLockController = [[PAPasscodeViewController alloc] initForAction:PasscodeActionSet];
             passcodeLockController.delegate = self;
             UINavigationController *navigationController = [[UINavigationController alloc] initWithRootViewController:passcodeLockController];
+            // Specify modal presentation style due to iOS 13 behaviour
+            navigationController.modalPresentationStyle = UIModalPresentationFullScreen;
             [self.navigationController presentViewController:navigationController animated:YES completion:nil];
         }
     }
-    if ([notification.object isEqual:kVLCSettingAppTheme]) {
-        BOOL darkTheme = [[notification.userInfo objectForKey:kVLCSettingAppTheme] boolValue];
-        PresentationTheme.current = darkTheme ? PresentationTheme.darkTheme : PresentationTheme.brightTheme;
-    }
 }
 
 - (void)showAbout
@@ -234,7 +232,7 @@ NSString * const kVLCSectionTableHeaderViewIdentifier = @"VLCSectionTableHeaderV
     actionSheet.delegate = specifierManager;
     actionSheet.dataSource = specifierManager;
     
-    [self presentViewController:actionSheet animated:YES completion:^{
+    [self presentViewController:actionSheet animated:NO completion:^{
         [self->actionSheet.collectionView selectItemAtIndexPath:self->specifierManager.selectedIndex animated:NO scrollPosition:UICollectionViewScrollPositionCenteredVertically];
     }];
 }
